==> haskell-network-control-0.0.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-control.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-control
version:              0.0.2
visibility:           public
id:                   network-control-0.0.2-AilRPibtRIJ8mwagJBpdVX
key:                  network-control-0.0.2-AilRPibtRIJ8mwagJBpdVX
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             Library to control network protocols
description:          Common parts to control network protocols
category:             Network
abi:                  0ab4925637ab1b89eaced61f18f4ef52
exposed:              True
exposed-modules:      Network.Control
hidden-modules:
    Network.Control.Flow Network.Control.LRUCache Network.Control.Rate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-control-0.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-control-0.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-control-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-control
hs-libraries:         HSnetwork-control-0.0.2-AilRPibtRIJ8mwagJBpdVX
depends:
    base-4.17.2.1 psqueues-0.2.8.1-DxDO26kNq4rHSmn1mtm535
    unix-time-0.4.16-HyqItAaU4OS97Wsaoufosq

haddock-interfaces:
    /usr/share/doc/haskell-network-control/html/network-control.haddock

haddock-html:         /usr/share/doc/haskell-network-control/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-control-0.0.2-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-control.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-control
version:              0.0.2
visibility:           public
id:                   network-control-0.0.2-41M76IFvaqHGEiX5N6gJNB
key:                  network-control-0.0.2-41M76IFvaqHGEiX5N6gJNB
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             Library to control network protocols
description:          Common parts to control network protocols
category:             Network
abi:                  12c6f25d14d0da1c38e03a7beffb6656
exposed:              True
exposed-modules:      Network.Control
hidden-modules:
    Network.Control.Flow Network.Control.LRUCache Network.Control.Rate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-control-0.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-control-0.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-control-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-control
hs-libraries:         HSnetwork-control-0.0.2-41M76IFvaqHGEiX5N6gJNB
depends:
    base-4.17.2.1 psqueues-0.2.8.1-DTqsCX8QhzS6tMZ39p8t6V
    unix-time-0.4.16-It4iq9a58TpIme4pdNTi1t

haddock-interfaces:
    /usr/share/doc/haskell-network-control/html/network-control.haddock

haddock-html:         /usr/share/doc/haskell-network-control/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
